==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/sv.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagring är temporärt inte tillgänglig",
    "Storage invalid" : "Lagring ogiltig",
    "Unknown error" : "Okänt fel",
    "All files" : "Alla filer",
    "Saved" : "Sparad",
    "File could not be found" : "Fil kunde inte hittas",
    "Home" : "Hem",
    "Close" : "Stäng",
    "Favorites" : "Favoriter",
    "Could not create folder \"{dir}\"" : "Kunde inte skapa mapp \"{dir}\"",
    "Upload cancelled." : "Uppladdning avbruten.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan inte ladda upp {filename} eftersom den antingen är en mapp eller har 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Inte tillräckligt med ledigt utrymme, du laddar upp {size1} men endast {size2} finns kvar.",
    "Target folder \"{dir}\" does not exist any more" : "Destinationsmappen \"{dir}\" finns inte längre",
    "Not enough free space" : "Inte tillräckligt med ledigt utrymme",
    "Uploading..." : "Laddar upp...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Filuppladdning pågår. Lämnar du sidan så avbryts uppladdningen.",
    "Actions" : "Åtgärder",
    "Download" : "Ladda ner",
    "Rename" : "Byt namn",
    "Delete" : "Radera",
    "Disconnect storage" : "Koppla bort lagring",
    "Unshare" : "Sluta dela",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select" : "Välj",
    "Pending" : "Väntar",
    "Unable to determine date" : "Misslyckades avgöra datum",
    "Invalid path" : "Ogiltig sökväg",
    "This operation is forbidden" : "Denna operation är förbjuden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, kontrollera loggarna eller kontakta administratören",
    "Could not move \"{file}\", target exists" : "Kunde inte flytta \"{file}\", filen existerar redan",
    "Could not move \"{file}\"" : "Kunde inte flytta \"{file}\"",
    "{newName} already exists" : "{newName} existerar redan",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kunde inte döpa om \"{fileName}\", filen existerar inte mer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{targetName}\" används redan i mappen \"{dir}\". Vänligen välj ett annat namn.",
    "Could not rename \"{fileName}\"" : "Kan inte döpa om \"{fileName}\"",
    "Could not create file \"{file}\"" : "Kunde inte skapa fil \"{fileName}\"",
    "Could not create file \"{file}\" because it already exists" : "Kunde inte skapa fil \"{file}\" därför att den redan existerar",
    "Could not create folder \"{dir}\" because it already exists" : "Kunde inte skapa \"{dir}\" därför att den redan existerar",
    "Error deleting file \"{fileName}\"." : "Fel när \"{fileName}\" skulle raderas.",
    "Name" : "Namn",
    "Size" : "Storlek",
    "Modified" : "Ändrad",
    "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} och {files}",
    "_including %n hidden_::_including %n hidden_" : ["inklusive %n dold","inklusive %n dolda"],
    "You don’t have permission to upload or create files here" : "Du har ej tillåtelse att ladda upp eller skapa filer här",
    "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
    "New" : "Ny",
    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltligt filnamn.",
    "File name cannot be empty." : "Filnamn kan inte vara tomt.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagring av {owner}  är full, filer kan inte uppdateras eller synkroniseras längre!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagring av  {owner}  är nästan full  ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ditt lagringsutrymme är nästan fullt ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["matchar '{filter}'","matcha '{filter}'"],
    "Path" : "sökväg",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favorited" : "Favoriserad",
    "Favorite" : "Favorit",
    "Folder" : "Mapp",
    "New folder" : "Ny mapp",
    "{newname} already exists" : "{newname}  existerar redan",
    "Upload" : "Ladda upp",
    "An error occurred while trying to update the tags" : "Ett fel uppstod när uppdatera taggarna",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapp har blivit <strong>skapad</strong>",
    "A file or folder has been <strong>changed</strong>" : "En ny fil eller mapp har blivit <strong>ändrad</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begränsa notiser om skapande och ändringar till dina <strong>favoritfiler</strong> <em>(Endast ström)</em>",
    "A file or folder has been <strong>deleted</strong>" : "En ny fil eller mapp har blivit <strong>raderad</strong>",
    "A file or folder has been <strong>restored</strong>" : "En ny fil eller mapp har blivit <strong>återskapad</strong>",
    "You created %1$s" : "Du skapade %1$s",
    "%2$s created %1$s" : "%2$s skapade %1$s",
    "%1$s was created in a public folder" : "%1$s skapades i en publik mapp",
    "You changed %1$s" : "Du ändrade %1$s",
    "%2$s changed %1$s" : "%2$s ändrade %1$s",
    "You deleted %1$s" : "Du raderade %1$s",
    "%2$s deleted %1$s" : "%2$s raderade %1$s",
    "You restored %1$s" : "Du återkapade %1$s",
    "%2$s restored %1$s" : "%2$s återskapade %1$s",
    "Changed by %2$s" : "Ändrad av %2$s",
    "Deleted by %2$s" : "Bortagen av %2$s",
    "Restored by %2$s" : "Återställd av %2$s",
    "Upload (max. %s)" : "Ladda upp (max. %s)",
    "File handling" : "Filhantering",
    "Maximum upload size" : "Maximal storlek att ladda upp",
    "max. possible: " : "max. möjligt:",
    "Save" : "Spara",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det ta cirka 5 minuter för ändringarna att träda i kraft.",
    "Missing permissions to edit from here." : "Saknar rättigheter att ändra härifrån.",
    "Settings" : "Inställningar",
    "Show hidden files" : "Visa dolda filer",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Använd den här adressen för att <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">komma åt dina filer via WebDAV</a>",
    "No files in here" : "Inga filer kunde hittas",
    "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
    "No entries found in this folder" : "Inga innehåll hittades i denna mapp",
    "Select all" : "Välj allt",
    "Upload too large" : "För stor uppladdning",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
    "No favorites" : "Inga favoriter",
    "Files and folders you mark as favorite will show up here" : "Filer och mappar du markerat som favoriter kommer att visas här",
    "Text file" : "Textfil",
    "New text file.txt" : "nytextfil.txt",
    "Target folder does not exist any more" : "Målmappen finns inte längre",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Privat länk: Bara de som har tillgång till filen/mappen kan använda den. Använd den som en permanent länk för dig själv eller peka andra till filer inuti delningar",
    "Upload timeout for file \"{file}\"" : "Uppadddnings-timeout för fil \"{file}\"",
    "Processing files..." : "Behandlar filer ...",
    "No entries in this folder match {filter}" : "Inga poster i mappen matchar {filter}",
    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "Begränsa meddelanden om att skapa och ändra till dina <strong>favoritfiler</strong>",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Du har inte behörighet att komma åt denna fil/mapp - Kontakta ägaren för att dela den med dig.",
    "Error when assembling chunks, status code {status}" : "Fel vid sammanställning av bitar, statuskod {status}",
    "Unknown user" : "Okänd användare"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/sv.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagring är temporärt inte tillgänglig",
    "Storage invalid" : "Lagring ogiltig",
    "Unknown error" : "Okänt fel",
    "All files" : "Alla filer",
    "File could not be found" : "Filen ej funnen",
    "Home" : "Hem",
    "Close" : "Stäng",
    "Favorites" : "Favoriter",
    "Upload timeout for file \"{file}\"" : "Uppadddnings-timeout för fil \"{file}\"",
    "Unknown error \"{error}\" uploading file \"{file}\"" : "Okänt fel \"{error}\" vid uppladdning av fil \"{file}\"",
    "Could not create folder \"{dir}\"" : "Kan inte skapa mapp \"{dir}\"",
    "Upload cancelled." : "Uppladdning avbruten.",
    "Processing files..." : "Behandlar filer ...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan inte ladda upp {filename} eftersom den antingen är en mapp eller har 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Inte tillräckligt med ledigt utrymme, du laddar upp {size1} men endast {size2} finns kvar.",
    "Target folder \"{dir}\" does not exist any more" : "Destinationsmappen \"{dir}\" finns inte längre",
    "Target folder does not exist any more" : "Målmappen finns inte längre",
    "Not enough free space" : "Inte tillräckligt med ledigt utrymme",
    "Uploading..." : "Laddar upp...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "Error when assembling chunks, status code {status}" : "Fel vid sammanställning av bitar, statuskod {status}",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Filuppladdning pågår. Lämnar du sidan så avbryts uppladdningen.",
    "Actions" : "Åtgärder",
    "Download" : "Ladda ner",
    "Rename" : "Byt namn",
    "Delete" : "Ta bort",
    "Disconnect storage" : "Koppla bort lagring",
    "Unshare" : "Sluta dela",
    "Could not load info for file \"{file}\"" : "Kan inte ladda info för filen \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select" : "Välj",
    "Pending" : "Väntar",
    "Unable to determine date" : "Misslyckades avgöra datum",
    "Invalid path" : "Ogiltig sökväg",
    "This operation is forbidden" : "Denna operation är förbjuden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, kontrollera loggarna eller kontakta administratören",
    "group" : "Grupp",
    "Remote share" : "Fjärrdelning",
    "Could not move \"{file}\", target exists" : "Kan inte flytta \"{file}\", filen finns redan",
    "Could not move \"{file}\"" : "Kan inte flytta \"{file}\"",
    "{newName} already exists" : "{newName} finns redan",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kan inte döpa om \"{fileName}\", filen finns inte längre",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{targetName}\" används redan i mappen \"{dir}\". Välj ett annat namn.",
    "Could not rename \"{fileName}\"" : "Kan inte döpa om \"{fileName}\"",
    "Could not create file \"{file}\"" : "Kan inte skapa fil \"{fileName}\"",
    "Could not create file \"{file}\" because it already exists" : "Kan inte skapa fil \"{file}\" därför att den redan finns",
    "Could not create folder \"{dir}\" because it already exists" : "Kan inte skapa \"{dir}\" därför att den redan finns",
    "Error deleting file \"{fileName}\"." : "Fel när \"{fileName}\" skulle raderas.",
    "No entries in this folder match {filter}" : "Inga poster i mappen matchar {filter}",
    "Name" : "Namn",
    "Size" : "Storlek",
    "Modified" : "Ändrad",
    "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} och {files}",
    "_including %n hidden_::_including %n hidden_" : ["inklusive %n dold","inklusive %n dolda"],
    "You don’t have permission to upload or create files here" : "Du har ej tillåtelse att ladda upp eller skapa filer här",
    "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
    "New" : "Ny",
    "Unknown user" : "Okänd användare",
    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltligt filnamn.",
    "File name cannot be empty." : "Filnamn kan inte vara tomt.",
    "File name cannot contain \"/\"." : "Filnamnet får inte innehålla \"/\".",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" har en förbjuden filtyp/filtillägg",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagring av {owner}  är full, filer kan inte uppdateras eller synkroniseras längre!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagring av  {owner}  är nästan full  ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ditt lagringsutrymme är nästan fullt ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["matchar '{filter}'","matcha '{filter}'"],
    "Path" : "sökväg",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favorited" : "I Favoriter",
    "Favorite" : "Favorit",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Privat länk: Bara de som har tillgång till filen/mappen kan använda den. Använd den som en permanent länk för dig själv eller peka andra till filer inuti delningar",
    "Folder" : "Mapp",
    "New folder" : "Ny mapp",
    "{newname} already exists" : "{newname}  finns redan",
    "Upload" : "Ladda upp",
    "An error occurred while trying to update the tags" : "Ett fel uppstod när uppdatera taggarna",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapp har blivit <strong>skapad</strong>",
    "A file or folder has been <strong>changed</strong>" : "En ny fil eller mapp har blivit <strong>ändrad</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begränsa notiser om skapande och ändringar till dina <strong>favoritfiler</strong> <em>(Endast ström)</em>",
    "A file or folder has been <strong>deleted</strong>" : "En ny fil eller mapp har blivit <strong>raderad</strong>",
    "A file or folder has been <strong>restored</strong>" : "En ny fil eller mapp har blivit <strong>återskapad</strong>",
    "You created %1$s" : "Du skapade %1$s",
    "%2$s created %1$s" : "%2$s skapade %1$s",
    "%1$s was created in a public folder" : "%1$s skapades i en publik mapp",
    "You changed %1$s" : "Du ändrade %1$s",
    "%2$s changed %1$s" : "%2$s ändrade %1$s",
    "You deleted %1$s" : "Du raderade %1$s",
    "%2$s deleted %1$s" : "%2$s raderade %1$s",
    "You restored %1$s" : "Du återställde %1$s",
    "%2$s restored %1$s" : "%2$s återställda %1$s",
    "Changed by %2$s" : "Ändrad av %2$s",
    "Deleted by %2$s" : "Bortagen av %2$s",
    "Restored by %2$s" : "Återställd av %2$s",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Du har inte behörighet att komma åt denna fil/mapp - Kontakta ägaren för att dela den med dig.",
    "Upload (max. %s)" : "Ladda upp (max. %s)",
    "Settings" : "Inställningar",
    "Show hidden files" : "Visa dolda filer",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Använd den här adressen för att <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">komma åt dina filer via WebDAV</a>",
    "No files in here" : "Inga filer kunde hittas",
    "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
    "No entries found in this folder" : "Inga innehåll hittades i denna mapp",
    "Select all" : "Välj allt",
    "Upload too large" : "För stor uppladdning",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
    "No favorites" : "Inga favoriter",
    "Files and folders you mark as favorite will show up here" : "Filer och mappar du markerat som favoriter kommer att visas här",
    "Text file" : "Textfil",
    "New text file.txt" : "nytextfil.txt"
},
"nplurals=2; plural=(n != 1);");
